extension DateExtensions on DateTime {
  bool isWeekend() {
    return weekday == DateTime.saturday || weekday == DateTime.sunday;
  }

  int getDaysUntil(DateTime other) {
    return other.difference(this).inDays;
  }

  bool isLeapYear() {
    return (year % 4 == 0 && year % 100 != 0) || year % 400 == 0;
  }

  int getAge(DateTime birthdate) {
    int age = DateTime.now().year - birthdate.year;
    int monthDiff = DateTime.now().month - birthdate.month;
    if (monthDiff < 0 ||
        (monthDiff == 0 && DateTime.now().day < birthdate.day)) {
      age--;
    }
    return age;
  }

  bool isSameDay(DateTime other) {
    return year == other.year && month == other.month && day == other.day;
  }

  int getDifference(DateTime other, {String unit = "days"}) {
    Duration difference = other.difference(this);
    switch (unit) {
      case "days":
        return difference.abs().inDays;
      case "hours":
        return difference.abs().inHours;
      case "minutes":
        return difference.abs().inMinutes;
      case "seconds":
        return difference.abs().inSeconds;
      default:
        return difference.abs().inDays;
    }
  }

  String getTimeOfDay() {
    int hour = this.hour;
    if (hour < 6) {
      return "night";
    } else if (hour < 12) {
      return "morning";
    } else if (hour < 17) {
      return "afternoon";
    } else if (hour < 21) {
      return "evening";
    }
    return "night";
  }
}
